=======================
ProbabilityDict2D class
=======================

This class is same as the `ProbabilityDict class <ProbabilityDict.html>`_ but
instead of storing the one dimensional PDFs for a given parameter, it stores
the 2D PDF for 2 parameters. The 2D analytic PDF is stored as a
`DiscretePDF2D object <pdf.html>`_.

.. autoclass:: pesummary.utils.probability_dict.ProbabilityDict2D
